@@ -1,9 +1,8 @@
-#!/usr/bin/env python
-# -*- coding: utf-8  -*-
+# -*- coding: utf-8 -*-
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2012 Lance Edgar
+#  Copyright © 2010-2014 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -26,6 +25,8 @@
 Product Field Renderers
 """
 
+from __future__ import unicode_literals
+
 from formalchemy import TextFieldRenderer
 from rattail.gpc import GPC
 from .common import AutocompleteFieldRenderer
@@ -88,19 +89,20 @@ class PriceFieldRenderer(TextFieldRenderer):
     def render_readonly(self, **kwargs):
         price = self.field.raw_value
         if price:
-            if price.price is not None and price.pack_price is not None:
-                if price.multiple > 1:
-                    return literal('$ %0.2f / %u&nbsp; ($ %0.2f / %u)' % (
-                            price.price, price.multiple,
-                            price.pack_price, price.pack_multiple))
-                return literal('$ %0.2f&nbsp; ($ %0.2f / %u)' % (
-                        price.price, price.pack_price, price.pack_multiple))
-            if price.price is not None:
-                if price.multiple > 1:
-                    return '$ %0.2f / %u' % (price.price, price.multiple)
-                return '$ %0.2f' % price.price
-            if price.pack_price is not None:
-                return '$ %0.2f / %u' % (price.pack_price, price.pack_multiple)
+            if not price.product.not_for_sale:
+                if price.price is not None and price.pack_price is not None:
+                    if price.multiple > 1:
+                        return literal('$ %0.2f / %u&nbsp; ($ %0.2f / %u)' % (
+                                price.price, price.multiple,
+                                price.pack_price, price.pack_multiple))
+                    return literal('$ %0.2f&nbsp; ($ %0.2f / %u)' % (
+                            price.price, price.pack_price, price.pack_multiple))
+                if price.price is not None:
+                    if price.multiple > 1:
+                        return '$ %0.2f / %u' % (price.price, price.multiple)
+                    return '$ %0.2f' % price.price
+                if price.pack_price is not None:
+                    return '$ %0.2f / %u' % (price.pack_price, price.pack_multiple)
         return ''
 
 
