@@ -190,7 +190,9 @@ class ProductsGrid(SearchableAlchemyGridView):
         return q
 
     def grid(self):
-        g = self.make_grid()
+        def extra_row_class(row, i):
+            return 'not-for-sale' if row.not_for_sale else None
+        g = self.make_grid(extra_row_class=extra_row_class)
         g.upc.set(renderer=GPCFieldRenderer)
         g.regular_price.set(renderer=PriceFieldRenderer)
         g.current_price.set(renderer=PriceFieldRenderer)
@@ -264,6 +266,7 @@ class ProductCrud(CrudView):
                 fs.report_code,
                 fs.regular_price,
                 fs.current_price,
+                fs.not_for_sale,
                 ])
         if not self.readonly:
             del fs.regular_price
